@@ -3,7 +3,7 @@ set -ex
 
 
 #---
-#   MinGW cross compiling environment  (1.2)
+#   MinGW cross compiling environment  (1.3)
 #   =================================
 #
 #   http://www.profv.de/mingw_cross_env/
@@ -120,12 +120,12 @@ VERSION_libxml2=2.6.30
 VERSION_libxslt=1.1.22
 VERSION_xmlwrapp=0.5.0
 VERSION_curl=7.17.1
-VERSION_libpng=1.2.23
+VERSION_libpng=1.2.24
 VERSION_jpeg=6b
 VERSION_tiff=3.8.2
 VERSION_giflib=4.1.6
 VERSION_freetype=2.3.5
-VERSION_fontconfig=2.4.2
+VERSION_fontconfig=2.5.0
 VERSION_libmikmod=3.2.0-beta2
 VERSION_ogg=1.1.3
 VERSION_vorbis=1.2.0
@@ -138,7 +138,7 @@ VERSION_fltk=1.1.7
 VERSION_geos=3.0.0rc5
 VERSION_proj=4.5.0
 VERSION_libgeotiff=1.2.4
-VERSION_gdal=1.4.2
+VERSION_gdal=1.4.4
 VERSION_pdflib_lite=7.0.2
 VERSION_libowfat=0.26
 
@@ -174,6 +174,7 @@ case "$1" in
     rm -rf "mingw_cross_env-$VERSION"
     mkdir  "mingw_cross_env-$VERSION"
     cp "$0" README ChangeLog "mingw_cross_env-$VERSION/"
+    cp fontconfig-2.5.0-crosscompile.patch "mingw_cross_env-$VERSION/"
     tar cfv - "mingw_cross_env-$VERSION" | gzip -9 >"mingw_cross_env-$VERSION.tar.gz"
     rm -rf "mingw_cross_env-$VERSION"
     exit 0
@@ -1325,18 +1326,21 @@ case "$1" in
     cd "$SOURCE"
     tar xfvz "$DOWNLOAD/fontconfig-$VERSION_fontconfig.tar.gz"
     cd "fontconfig-$VERSION_fontconfig"
+    # apply a portability patch
+    patch -p1 <"$ROOT/fontconfig-2.5.0-crosscompile.patch"
+    # ensure there is no (buggy) attempt to install the *.dll.a file
+    # (remove this line of you want to link dynamically)
     $SED 's,^install-data-local:.*,install-data-local:,' -i src/Makefile.in
     ./configure \
         --host="$TARGET" \
         --disable-shared \
         --prefix="$PREFIX/$TARGET" \
-        --with-arch="" \
+        --with-arch="$TARGET" \
         --with-freetype-config="$PREFIX/$TARGET/bin/freetype-config" \
         --enable-libxml2 \
         LIBXML2_CFLAGS="`$PREFIX/$TARGET/bin/xml2-config --cflags`" \
         LIBXML2_LIBS="`$PREFIX/$TARGET/bin/xml2-config --libs`"
-    $MAKE install -C src
-    $MAKE install -C fontconfig
+    $MAKE install bin_PROGRAMS= sbin_PROGRAMS= noinst_PROGRAMS=
     cd "$SOURCE"
     rm -rfv "fontconfig-$VERSION_fontconfig"
     ;;
@@ -1766,7 +1770,7 @@ case "$1" in
 --download)
     cd "$DOWNLOAD"
     tar tfj "geos-$VERSION_geos.tar.bz2" &>/dev/null ||
-    wget -c "http://geos.refractions.net/geos-$VERSION_geos.tar.bz2"
+    wget -c "http://geos.refractions.net/downloads/geos-$VERSION_geos.tar.bz2"
     ;;
 
 --build)
